import Image from "next/image";
import { useRouter } from "next/router";

import { useTranslation } from "next-i18next";

import { Button, Card, Grid, Space } from "@mantine/core";

import { Icon, ICONS } from "vseth-canine-ui";

import board from "../content/board.json";

export default function About() {
  const { t } = useTranslation("common");
  const { locale } = useRouter();

  return (
    <>
      <h1>{t("about")}</h1>

      <Grid style={{ justifyContent: "center" }}>
        {board.map((entry) => (
          <Grid.Col md={3} sm={4} xs={6}>
            <Card shadow="sm" radius="md" withBorder>
              <Card.Section
                style={{
                  position: "relative",
                  aspectRatio: "1/1",
                  overflow: "hidden",
                  marginBottom: "16px",
                }}
              >
                <Image
                  src={entry.image}
                  width={0}
                  height={0}
                  sizes="100vw"
                  style={{ width: "100%", height: "auto" }}
                  alt={entry.name}
                />
              </Card.Section>
              <h2 style={{ margin: 0 }}>{entry.name}</h2>
              <p>{entry.role[locale || "en"]}</p>
              <Space h="sm" />
              <a href={"mailto:" + entry.mail}>
                <Button leftIcon={<Icon icon={ICONS.EMAIL} color="white" />}>
                  {t("contact")}
                </Button>
              </a>
            </Card>
          </Grid.Col>
        ))}
      </Grid>
    </>
  );
}
