import React, { ReactNode, useState } from "react";
import Link from "next/link";
import { useRouter } from "next/router";

import { useTranslation } from "next-i18next";
import { useSession } from "next-auth/react";

import { NotificationsProvider } from "@mantine/notifications";

import { ApolloProvider } from "@apollo/client";
import apolloClient from "../lib/apollo";

import {
  makeVsethTheme,
  useConfig,
  VSETHExternalApp,
  VSETHThemeProvider,
} from "vseth-canine-ui";

import hasAccess from "../utilities/hasAccess";

import LoginButton from "../components/loginButton";

export default function Navbar(props) {
  const router = useRouter();
  const { locale, pathname, asPath, query } = router;
  const { t } = useTranslation("common");
  const { data: session } = useSession();

  const theme = makeVsethTheme();
  const [selectedLanguage, setSelectedLanguage] = React.useState(locale);

  /*
   * VSETH Colors: See https://s.aschoch.ch/canine-colors
   * theme.colors.vsethMain[7] is #009fe3 (cyan)
   */
  theme.colors.vsethMain[7] = "#244471";
  theme.colors.vsethMain[0] = "#b7cae5"; // light color
  theme.colors.vsethMain[1] = "#b7cae5"; // light color
  theme.colors.vsethMain[8] = "#4f6d96"; // light color

  const { data } = useConfig(
    "https://static.vseth.ethz.ch/assets/vseth-0522-thealt/config.json"
  );

  const customDemoNav = [
    { title: t("main"), href: "/" },
    { title: t("bashGuide"), href: "/bash" },
    { title: t("installGuide"), href: "/install" },
    {
      title: t("courses"),
      href: "https://gitlab.ethz.ch/thealternative/courses",
    },
  ];

  // if (hasAccess(session, true)) {
  //   customDemoNav.push({ title: t("menu"), href: "/menu" });
  //   customDemoNav.push({ title: t("graveyard"), href: "/graveyard" });
  // }

  return (
    <React.StrictMode>
      <VSETHThemeProvider theme={theme}>
        <VSETHExternalApp
          selectedLanguage={selectedLanguage}
          onLanguageSelect={(lang) => {
            setSelectedLanguage(lang);
            router.push({ pathname, query }, asPath, { locale: lang });
          }}
          languages={data?.languages}
          title={"TheAlternative"}
          appNav={customDemoNav}
          organizationNav={data.externalNav}
          makeWrapper={(url, child) => (
            <Link
              href={url}
              style={{ textDecoration: "none", color: "inherit" }}
            >
              {child}
            </Link>
          )}
          privacyPolicy={data?.privacy}
          disclaimer={data?.copyright}
          //activeHref is the current active url path. Required to style the active page in the Nav
          activeHref={"/"}
          socialMedia={data?.socialMedia}
          logo={
            "https://static.vseth.ethz.ch/assets/vseth-0522-thealt/logo-inv.svg"
          }
          loginButton={<LoginButton />}
          signet={
            "https://static.vseth.ethz.ch/assets/vseth-0522-thealt/signet-inv.svg"
          }
          size="xl"
        >
          <ApolloProvider client={apolloClient}>
            <NotificationsProvider>{props.children}</NotificationsProvider>
          </ApolloProvider>
        </VSETHExternalApp>
      </VSETHThemeProvider>
    </React.StrictMode>
  );
}
